@@ -448,33 +448,6 @@ def import_pylab(user_ns, import_all=True):
     user_ns['getfigs'] = getfigs
 
 
-def configure_inline_support(shell, backend):
-    """
-    .. deprecated:: 7.23
-
-        use `matplotlib_inline.backend_inline.configure_inline_support()`
-
-    Configure an IPython shell object for matplotlib use.
-
-    Parameters
-    ----------
-    shell : InteractiveShell instance
-    backend : matplotlib backend
-    """
-    warnings.warn(
-        "`configure_inline_support` is deprecated since IPython 7.23, directly "
-        "use `matplotlib_inline.backend_inline.configure_inline_support()`",
-        DeprecationWarning,
-        stacklevel=2,
-    )
-
-    from matplotlib_inline.backend_inline import (
-        configure_inline_support as configure_inline_support_orig,
-    )
-
-    configure_inline_support_orig(shell, backend)
-
-
 # Determine if Matplotlib manages backends only if needed, and cache result.
 # Do not read this directly, instead use _matplotlib_manages_backends().
 _matplotlib_manages_backends_value: bool | None = None
